
/*
 *  Copyright (C) 2018 Juergen Platzer 
 * 
 *  This file is part of GpxParser.
 *  
 *  GpxParser is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *  
 *  GpxParser is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *  
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with GpxParser.  If not, see <http://www.gnu.org/licenses/>.
 */

import java.util.Date;
import java.text.SimpleDateFormat;

public class Target {

  

  /*** member variables ***/
  private String m_pName;
  private double m_dElevation;
  private Date m_pTime;
  private boolean m_bIsTargetLeave;
  
  ////////////////////////////////
  // CONSTRUCTOR                //
  ////////////////////////////////
  public Target(String pName, String pTime, String pElevation) {
    this(pName, pTime, pElevation, false);
  }
  
  public Target(String pName, String pTime, String pElevation, boolean bIsTargetLeave) {
    
    m_pName = Utilities.replaceSpecialCharacters(pName);
    m_pTime = Utilities.getTimeFromXml(pTime);
    m_dElevation = Utilities.getDouble(pElevation);
    m_bIsTargetLeave = bIsTargetLeave;
  }
  
  ////////////////////////////////
  // GET METHODS                //
  ////////////////////////////////
  public String getName() {
    return m_pName;
  }

  public String getTimeForHtml() {
    return Utilities.getTimeForHtml(m_pTime);
  }

  public double getElevation() {
    return m_dElevation;
  }

  public String getElevationForHtml() {
    return ((int)m_dElevation) + " m";
  }
  
  public long getTimeInMilliseconds() {
    return Utilities.getTimeInMilliseconds(m_pTime);
  }
  
  public int getAbsoluteMinuteDifference(Target pOtherTarget) {
    if (pOtherTarget == null) return 0;

    long lDifference = Math.abs(getTimeInMilliseconds() - pOtherTarget.getTimeInMilliseconds());
    return (int)(lDifference/1000/60);
  }
  
  public boolean isTargetLeave() {
    return m_bIsTargetLeave;
  }
  
  public double getKilometers() {
    //TO DO: set the kilometers in a calculation!!!
    return -1;
  }
    
    
}