
/*
 *  Copyright (C) 2018 Juergen Platzer 
 * 
 *  This file is part of GpxParser.
 *  
 *  GpxParser is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *  
 *  GpxParser is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *  
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with GpxParser.  If not, see <http://www.gnu.org/licenses/>.
 */

import java.util.Vector;
import java.util.Properties;
import java.io.File;

public class TestGpxParser {
  
  private String m_strGpx, m_strTimeStatistic, m_strTimeStatisticTemp;
  
  ///////////////////////////////
  // CONSTRUCTOR               //
  ///////////////////////////////
  public TestGpxParser(String strGpxFile, String strTimeStatisticFile) throws Exception {
    m_strGpx = Utilities.prepareString(strGpxFile);
    m_strTimeStatistic = Utilities.prepareString(strTimeStatisticFile);
    m_strTimeStatisticTemp = m_strTimeStatistic + "_temp";
    
    if (!FileUtilities.fileExists(strGpxFile)) throw new Exception("The file specified GpxFile " + m_strGpx + " does not exist!");
    if (!FileUtilities.fileExists(strTimeStatisticFile)) throw new Exception("The file specified time statistics file " + m_strTimeStatistic + " does not exist!");
    
  }
  
  
  public void test() throws Exception {
    //1. Create the Configuration for the Test
    Properties pProperties = new Properties();
    pProperties.put("InputFile", m_strGpx);
    pProperties.put("HeightAnalysisOutput", "HeightAnalysisOutput.csv");
    pProperties.put("TimeStatisticOutput", m_strTimeStatisticTemp);
    pProperties.put("ConsiderHeights", "1");
    Configuration pConfiguration = new Configuration(pProperties);


    //2. Create the GPXParser and create the time analysis 
    GpxParser pParser = new GpxParser(pConfiguration);
    pParser.writeTimeStatistic();
    
    //3. compare the newly created time analysis with the actual test 
    TextFileComparer pComparer = new TextFileComparer(m_strTimeStatistic, m_strTimeStatisticTemp);
    Vector<TextLineDifference> pDifferences = pComparer.getTextLineDifferences();
    int iDiffNum = pDifferences.size();
    if (iDiffNum > 0) {
      String strError = "";
      for (int i = 0; i < iDiffNum; i++) {
        strError += pDifferences.get(i).toString() + "\n";
      }
      throw new Exception("Differences in " + m_strTimeStatistic + ":\n\n" + strError);
    }
    
    
    
    
    //4. delete the newly created time analysis
    File fTempFile = new File(m_strTimeStatisticTemp);
    fTempFile.delete();
  }
  
  
  
  ///////////////////////////////
  // TEST START                //
  ///////////////////////////////
  public static void main(String[] args) throws Exception {
    
    TestGpxParser pTest = null;
    String pErrors = "";
    
    Vector<String> pGpxFiles = new Vector<String>();
    Vector<String> pHtmlFiles = new Vector<String>();
    
    pGpxFiles.add("test/20160720_extended.gpx");
    pHtmlFiles.add("test/20160720_time.html");
    
    pGpxFiles.add("test/20170909_extended.gpx");
    pHtmlFiles.add("test/20170909_time.html");
    
    pGpxFiles.add("test/20161026_extended.gpx");
    pHtmlFiles.add("test/20161026_time.html");
    
    pGpxFiles.add("test/20141122_extended.gpx");
    pHtmlFiles.add("test/20141122_time.html");
    
    
    int iFileNum = pGpxFiles.size();
    for (int i = 0; i < iFileNum; i++) {
      try {
        pTest = new TestGpxParser(pGpxFiles.get(i), pHtmlFiles.get(i));
        pTest.test();
      }
      catch (Exception pException) {
        pErrors += pException.getMessage() + "\n\n";
      }
    }
    
    if (pErrors.length() > 0) {
      System.out.println(pErrors);
    }
    else {
      System.out.println("Everything OK");
    }
    
  }
  

}