
/*
 *  Copyright (C) 2018 Juergen Platzer 
 * 
 *  This file is part of GpxParser.
 *  
 *  GpxParser is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *  
 *  GpxParser is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *  
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with GpxParser.  If not, see <http://www.gnu.org/licenses/>.
 */


import java.util.Vector;
import java.io.BufferedReader;
import java.io.FileReader;

public class TextFileComparer {

  /*** member variables ***/
  private String m_strFile1, m_strFile2;

  
  /////////////////////////
  // CONSTRUCTOR         //
  /////////////////////////
  public TextFileComparer(String strFile1, String strFile2) throws Exception {
    //1. some checks
    m_strFile1 = Utilities.prepareString(strFile1);
    if (!FileUtilities.fileExists(m_strFile1)) throw new Exception("The first file for comparison '" + m_strFile1 + "' does not exist!");
    m_strFile2 = Utilities.prepareString(strFile2);
    if (!FileUtilities.fileExists(m_strFile2)) throw new Exception("The second file for comparison '" + m_strFile2 + "' does not exist!");
  }
  
  
  /////////////////////////
  // GET METHODS         //
  /////////////////////////
  public Vector<TextLineDifference> getTextLineDifferences() throws Exception {
    
    BufferedReader pReader1 = null;
    BufferedReader pReader2 = null;
    Vector<TextLineDifference> pDifferences = new Vector<TextLineDifference>();
    
    try {
      pReader1 = new BufferedReader(new FileReader(m_strFile1));
      pReader2 = new BufferedReader(new FileReader(m_strFile2));
      
      String strLine1 = pReader1.readLine();
      String strLine2 = pReader2.readLine();
      int iLineId = 1;
      
      
      while ((strLine1 != null) && (strLine2 != null)) {
        TextLineDifference tldDiff = new TextLineDifference(iLineId, strLine1, strLine2);
        if (tldDiff.isDifferent()) pDifferences.add(tldDiff);
        
        strLine1 = pReader1.readLine();
        strLine2 = pReader2.readLine();
        iLineId++;
      }
      
    }
    catch (Exception pException) {
      throw new Exception("Error on parsing the files to compare!", pException);
    }
    finally {
      if (pReader1 != null) pReader1.close();
      if (pReader2 != null) pReader2.close();
    }
    
    
    return pDifferences;
  }
  
  
  

}