
/*
 *  Copyright (C) 2018 Juergen Platzer 
 * 
 *  This file is part of GpxParser.
 *  
 *  GpxParser is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *  
 *  GpxParser is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *  
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with GpxParser.  If not, see <http://www.gnu.org/licenses/>.
 */


import java.text.DecimalFormat;
import java.text.DecimalFormatSymbols;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.Calendar;
import java.util.GregorianCalendar;
import java.util.Locale;



public class Utilities {

  /*** CONSTANTS ***/
  public static final DecimalFormat NUMBER_FORMAT = new DecimalFormat("#0.0#");
  public static final SimpleDateFormat XML_DATE_FORMAT = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss", Locale.GERMANY);
  public static final SimpleDateFormat KML_DATE_FORMAT = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss.SSS", Locale.GERMANY);
  public static final SimpleDateFormat XML_TIME_FORMAT = new SimpleDateFormat("HH:mm", Locale.GERMANY);
  public static final SimpleDateFormat HTML_TIME_FORMAT = new SimpleDateFormat("HH:mm",  Locale.GERMANY);

  //////////////////////////
  // GET METHODS          //
  //////////////////////////
  public static String prepareString(String pString) {
    if (pString == null) return "";
    return pString.trim();
  }
  
  public static String replaceSpecialCharacters(String pString) {
    pString = prepareString(pString);
    /*
    pString = pString.replace("�", "&uuml;");
    pString = pString.replace("�", "&Uuml;");
    pString = pString.replace("�", "&auml;");
    pString = pString.replace("�", "&Auml;");
    pString = pString.replace("�", "&ouml;");
    pString = pString.replace("�", "&Ouml;");
    */
    pString = pString.replace("\u00fc", "&uuml;");
    pString = pString.replace("\u00DC", "&Uuml;");
    pString = pString.replace("\u00E4", "&auml;");
    pString = pString.replace("\u00C4", "&Auml;");
    pString = pString.replace("\u00F6", "&ouml;");
    pString = pString.replace("\u00D6", "&Ouml;");
    pString = pString.replace("\u00DF", "&szlig;");
    pString = pString.replace("[br]", "<br/>");
    return pString;
  }
  
  public static String formatDouble(double dValue) {
    return NUMBER_FORMAT.format(dValue);
  }
  
  public static String formatDoubleEnglish(double dValue) {
    return (dValue + "").replace(",", ".");
  }
  
  public static double getDouble(String pValue) {
    try {
      return Double.parseDouble(pValue);
    }
    catch (Exception pException) {
      return Double.NaN;
    }
  }
  
  public static int getInt(String pValue) {
    try {
      return Integer.parseInt(pValue);
    }
    catch (Exception pException) {
      return Integer.MIN_VALUE;
    }
  }
  
  public static boolean getBoolean(String pValue) {
    if (pValue == null) return false;
    pValue = pValue.trim();
    if (pValue.equals("1")) return true;
    return false;
  }
  
  //2017-09-09T12:48:07Z
  public static Date getDateFromXml(String pValue) {
    try {
      pValue = pValue.replace("Z", "");
      pValue = pValue.replace("T", " ");
      return XML_DATE_FORMAT.parse(pValue);
    }
    catch (Exception pException) {
      return null;
    }
  }
  
  //2013-05-19T08:01:59.825Z
  public static Date getDateFromKml(String pValue) {
    try {
      pValue = pValue.replace("Z", "");
      pValue = pValue.replace("T", " ");
      return KML_DATE_FORMAT.parse(pValue);
    }
    catch (Exception pException) {
      return null;
    }
  }
  
  public static Date getTimeFromXml(String pValue) {
    try {
      return XML_TIME_FORMAT.parse(pValue);
    }
    catch (Exception pException) {
      return null;
    }
  }
  
  
  
  
  public static String getDateAsString(Date pDate) {
    if (pDate == null) return "null";
    return XML_DATE_FORMAT.format(pDate);
  }
  
  public static Date addHours(Date pDate, int iHours) {
    if (pDate == null) return null;
    
    GregorianCalendar pCalendar = new GregorianCalendar();
    pCalendar.setTime(pDate);
    pCalendar.add(Calendar.HOUR_OF_DAY, iHours);
    return pCalendar.getTime();
  }
  
  public static long getTimeInMilliseconds(Date pDate) {
    if (pDate == null) return 0;
    
    
    long lCompleteTimestamp = pDate.getTime();
    
    GregorianCalendar pCalendar = new GregorianCalendar(Locale.GERMANY);
    pCalendar.setTime(pDate);
    pCalendar.set(Calendar.HOUR_OF_DAY, 0);
    pCalendar.set(Calendar.MINUTE, 0);
    pCalendar.set(Calendar.SECOND, 0);
    pCalendar.set(Calendar.MILLISECOND, 0);
    
    return lCompleteTimestamp - pCalendar.getTimeInMillis();
    
    
    
  }
  
  public static int getAbsoluteMinuteDifference(String pTime1, String pTime2) {
    //TO DO: implement
    return -1;
  }
  
  public static String getTimeForHtml(Date pTime) {
    if (pTime == null) return "null";
    return HTML_TIME_FORMAT.format(pTime);
  }

}